Welcome to pgfinder's documentation!
=====================================

.. toctree::
    :maxdepth: 1
    :caption: Getting Started

    introduction
    installation
    usage
    pglang
    data_dictionary
    contributing
    smithereens
    copying

.. toctree::
   :maxdepth: 2
   :caption: API


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
